AudioIntervalClock class

An audio clock that ticks at a fixed interval.

This clock is useful for running audio task without blocking the isolate.

Inheritance
Available extensions

Constructors

AudioIntervalClock(AudioTime interval)
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

elapsedTime → AudioTime
The elapsed time of the clock.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
interval → AudioTime
The interval of the clock.
final
isStarted → bool
Whether the clock is started.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets the clock.
override
runWithBuffer({required AudioFrames frames, required bool onTick(AudioClock, AudioBuffer)}) → Future<void>

Available on AudioClock, provided by the AudioClockExtension extension

Runs the clock with an audio buffer while the onTick callback returns true.
start({required AudioClockCallback onTick}) → void
Starts the clock.
override
stop() → void
Stops the clock.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited