AudioTime class

A class for representing audio time.

Constructors

AudioTime(double seconds)
Constructs an AudioTime from seconds.
const
AudioTime.fromDuration(Duration duration)
Constructs an AudioTime from duration.
AudioTime.fromFrames(int frames, {required AudioFormat format})
Constructs an AudioTime from frames and format.

Properties

duration → Duration
Compute the Duration from seconds.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → double
Time in seconds.
final

Methods

computeFrames(AudioFormat format) → int
Compute the number of frames from format.
formatHHMMSS() → String
Format seconds as HH:MM:SS.
formatMMSS() → String
Format seconds as MM:SS.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(AudioTime other) → AudioTime
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator +(AudioTime other) → AudioTime
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator -(AudioTime other) → AudioTime
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator /(AudioTime other) → AudioTime
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator <(AudioTime other) → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator <=(AudioTime other) → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator ==(Object other) → bool
The equality operator.
override
operator >(AudioTime other) → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
operator >=(AudioTime other) → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Static Properties

zero ↔ AudioTime
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair