AudioDecoder class abstract

An abstract class for audio decoders.

Implementers

Constructors

AudioDecoder()

Properties

canSeek → bool
Whether the decoder supports seeking.
no setter
cursorInFrames ↔ int
The current position of the decoder in frames.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lengthInFrames → int?
The length of the audio in frames.
no setter
outputFormat → AudioFormat
Output format of the decoder.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode({required AudioBuffer destination}) → AudioDecodeResult
Decodes the audio into destination.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited