AudioDeviceContext class

The audio device context that is used to create audio devices for the specified backends.

Mixed-in types

Constructors

AudioDeviceContext({required List<AudioDeviceBackend> backends})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

activeBackend → AudioDeviceBackend
The active backend of the context.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this resource is already disposed.
no setterinherited
resourceId → int
The unique identifier of this resource.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearResourceFinalizer() → void
Clears the finalizer for this resource.
inherited
createCaptureDevice({required AudioFormat format, required int bufferFrameSize, AudioDeviceId? deviceId, bool noFixedSizedProcess = true, AudioDevicePerformanceProfile performanceProfile = AudioDevicePerformanceProfile.lowLatency, AudioFormatConverterConfig converter = const AudioFormatConverterConfig()}) → CaptureDevice
Create a capture device.
createPlaybackDevice({required AudioFormat format, required int bufferFrameSize, AudioDeviceId? deviceId, bool noFixedSizedProcess = true, AudioDevicePerformanceProfile performanceProfile = AudioDevicePerformanceProfile.lowLatency, AudioFormatConverterConfig converter = const AudioFormatConverterConfig()}) → PlaybackDevice
Create a playback device.
getDevices(AudioDeviceType type) → List<AudioDeviceInfo>
Get the available devices for the specified device type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setResourceFinalizer<T>(void onFinalize()) → void
Sets a finalizer for this resource.
inherited
throwIfDisposed() → void
Throws an AudioResourceDisposedException if this resource is already disposed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited