CaptureDeviceReadResult class

The result of the read operation.

Constructors

CaptureDeviceReadResult(MaResult maResult, int framesRead)
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
const

Properties

framesRead → int
The number of frames read from the device's internal buffer.
final
hashCode → int
The hash code for this object.
no setterinherited
maResult → MaResult
The miniaudio result of the read operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited