AudioEncoder class abstract

An abstract class for audio encoders.

Implementers

Constructors

AudioEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormat → AudioFormat
Input format of the encoder.
no setter
isStarted → bool
Whether the encoder is started or not.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode(AudioBuffer buffer) → AudioEncodeResult
Encodes the audio from buffer.
finalize() → void
Finishes encoding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Starts encoding.
throwIfNotStarted() → void
Throws a StateError if the encoder is not started.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited