CaContext class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Constructors

CaContext({required List<AudioDeviceBackend> backends, Pointer<ma_log>? pLog})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

activeBackend → AudioDeviceBackend
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setter
hashCode → int
The hash code for this object.
no setterinherited
ref → Pointer<ma_context>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDevice({required AudioFormat format, required int bufferFrameSize, required AudioDeviceType type, AudioDeviceId? deviceId, bool noFixedSizedProcess = true, AudioDevicePerformanceProfile performanceProfile = AudioDevicePerformanceProfile.lowLatency, AudioFormatConverterConfig converter = const AudioFormatConverterConfig()}) → CaDevice
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
dispose() → void
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getDevices(AudioDeviceType type) → List<AudioDeviceInfo>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited