CaDevice class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Constructors

CaDevice({required AudioDeviceType type, required CaContext context, required AudioFormat format, required int bufferFrameSize, AudioDeviceId? deviceId, bool noFixedSizedProcess = true, AudioDevicePerformanceProfile performanceProfile = AudioDevicePerformanceProfile.lowLatency, AudioFormatConverterConfig converter = const AudioFormatConverterConfig()})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

availableReadFrames → int
Available buffered frame count of the device. This value can be changed when isStarted flag is true.
no setter
availableWriteFrames → int
Available writable frame count of the device. This value can be changed when isStarted flag is true.
no setter
bufferFrameSize → int
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
context → CaContext
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
deviceInfo → AudioDeviceInfo?
Get the current device information. You can listen the notificationStream to detect device changes. When no device is specified while constructing the instance, this method returns null.
no setter
format → AudioFormat
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
A flag indicates the device is started or not.
no setter
notification → Stream<AudioDeviceNotification>
The device's notification stream. Use this stream to detecting route and lifecycle changes.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → AudioDeviceState
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setter
type → AudioDeviceType
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
volume ↔ double
The current volume of the device.
getter/setter pair

Methods

clearBuffer() → void
Clear the internal buffer.
dispose() → void
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(AudioBuffer buffer) → CaptureDeviceReadResult
Read device's internal buffer into buffer.
start() → void
Start the audio device.
stop({bool clearBuffer = true}) → void
Stop the audio device. When clearBuffer is set to true, internal buffer will be cleared automatically (true by default).
toString() → String
A string representation of this object.
inherited
write(AudioBuffer buffer) → PlaybackDeviceWriteResult
Write the buffer data to device's internal buffer. If you write frames greater than availableWriteFrames, overflowed frames will be ignored and not written.

Operators

operator ==(Object other) → bool
The equality operator.
inherited