AudioIsolate<TInitialMessage> class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Constructors

AudioIsolate(AudioIsolateWorker<TInitialMessage> _worker)
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLaunched → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach() → Future<AudioIsolateShutdownResponse>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
launch({TInitialMessage? initialMessage}) → Future<AudioIsolateLaunchedResponse>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<TResponse>(dynamic payload) → Future<TResponse?>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
shutdown() → Future<AudioIsolateShutdownResponse>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited