DelayNode class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance

Constructors

DelayNode({required int delayFrames, required bool delayStart, required AudioFormat format, required double decay, double dry = 1, double wet = 1})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

bypass ↔ bool
Whether the node is bypassed.
getter/setter pairinherited
decay ↔ double
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair
delayFrames → int
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
delayStart → bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
dry ↔ double
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair
format → AudioFormat
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
hashCode → int
The hash code for this object.
no setterinherited
inputBus → AudioInputBus
inputBus of this node.
latefinal
inputs → List<AudioInputBus>
The list of input buses.
no setterinherited
outputBus → AudioOutputBus
outputBus of this node.
latefinal
outputs → List<AudioOutputBus>
The list of output buses.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wet ↔ double
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(AudioBuffer buffer, bool isEnd) → AudioReadResult
Process the input buffer and return the result.
override
read(AudioOutputBus outputBus, AudioBuffer buffer) → AudioReadResult
Read audio data from the input bus and write audio data to the output bus.
inherited
reset() → void
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited