PlaybackNode class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance
Mixed-in types

Constructors

PlaybackNode({required PlaybackDevice device})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

device → PlaybackDevice
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
hashCode → int
The hash code for this object.
no setterinherited
inputBus → AudioInputBus
inputBus of this node.
latefinal
inputs → List<AudioInputBus>
The list of input buses.
no setterinherited
outputBus → AudioEndpointBus
outputBus of this node.
latefinal
outputs → List<AudioOutputBus>
The list of output buses.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(AudioOutputBus outputBus, AudioBuffer buffer) → AudioReadResult
Read audio data from the input bus and write audio data to the output bus.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited