VolumeNode class

VolumeNode is a node that changes the volume of the audio data.

Inheritance

Constructors

VolumeNode({required double volume})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

bypass ↔ bool
Whether the node is bypassed.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
inputBus → AudioInputBus
inputBus of this node.
latefinal
inputs → List<AudioInputBus>
The list of input buses.
no setterinherited
outputBus → AudioOutputBus
outputBus of this node.
latefinal
outputs → List<AudioOutputBus>
The list of output buses.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volume ↔ double
The volume of the audio data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(AudioBuffer buffer, bool isEnd) → AudioReadResult
Process the input buffer and return the result.
override
read(AudioOutputBus outputBus, AudioBuffer buffer) → AudioReadResult
Read audio data from the input bus and write audio data to the output bus.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited